==> aroundme_0_7_3.tar.gz: aroundme_0_7_3/aroundme/components/core/ann_list.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$menu_section = "structure";


if (!isset($_SESSION['user_id']) || $_SESSION['user_id'] < 1) {
	header("Location: index.php?" . strip_tags(SID));
	exit;
}

if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['int_announce']) {
	$output_access = true;
}


// SETUP ANNOUNCE
require_once ("class/Announce.class.php");
$announce = new Announce($db, $_SESSION['user_id']);

if (isset($_REQUEST['sort'])) {
	if ($_REQUEST['sort'] == "date") {
		$announce->order_by = "a.announce_create_datetime";
	}
	elseif ($_REQUEST['sort'] == "title") {
		$announce->order_by = "a.announce_title";
	}
	
	if (isset($_REQUEST['desc']) && $_REQUEST['desc'] == 1) {
		$announce->order_by .= " DESC";
	}
}



$output_announcements = $announce->selAnnouncements();

if (isset($output_announcements)) {
	$body->set('announcements', $output_announcements);
}


?>

==> aroundme_0_7_7.tar.gz: aroundme_0_7_7/aroundme/components/core/ann_list.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

$menu_section = "structure";


if (!isset($_SESSION['md5'])) {
	header("Location: index.php?http_referer=" . urlencode($_SERVER['REQUEST_URI']) . "&" . strip_tags(SID));
	exit;
}

if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['int_announce']) {
	$output_access = true;
}


// SETUP ANNOUNCE
require_once ("class/Announce.class.php");
$announce = new Announce($db, $_SESSION['user_id']);

if (isset($_REQUEST['sort'])) {
	if ($_REQUEST['sort'] == "date") {
		$announce->order_by = "a.announce_create_datetime";
	}
	elseif ($_REQUEST['sort'] == "title") {
		$announce->order_by = "a.announce_title";
	}
	
	if (isset($_REQUEST['desc']) && $_REQUEST['desc'] == 1) {
		$announce->order_by .= " DESC";
	}
}



$output_announcements = $announce->selAnnouncements();

if (isset($output_announcements)) {
	$body->set('announcements', $output_announcements);
}


?>
